            <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>Batches</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                            <table id="example" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th>Code</th>
                                        <th>Batch Name</th>
                                        <th>Status</th>
                                        <th></th>
                                        <th></th>
                                    </tr>
                                </thead>
                                <tbody>
                                     <tr>
                                        <td></td>                                                          
                                        <td></td>           
                                        <td></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
                                     </tr>
                                   </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            </div>
</div>
<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                Successfully done.
            </div>
            <div class="modal-footer">
                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Batch</h5>
               <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="Code_Err()"></input>
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Batch Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="BatchName" id="BatchName" placeholder="Batch Name" onkeypress="BatchName_Err()"></input>
                        <span id="ErrBatchName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6">
                        <label class="form-label">Starts</label><span style='color:red'>*</span>
                            <div class="input-group" name="Starting" id="Starting">
                           <select class="form-select form-select-sm" name="StartingYear" id="StartingYear" onchange="StartingYear_Err()">
                                <option value="0">Year</option>
                                <?php for($year=date("Y");$year>(date("Y")-60);$year--) { ?>
                                <option value="<?php echo $year; ?>" <?php echo ($_POST['CaseYear']==$year) ? " selected='selected' " : "";?>><?php echo $year; ?></option>
                                <?php } ?>
                           </select>
                            <div class="input-group-prepend">
                             <select class="form-select form-select-sm" name="StartingMonth" id="StartingMonth" onchange="StartingMonth_Err()">
                                <option value="0">Month</option>
                                <option value="JAN">January</option>
                                <option value="FEB">February</option>
                                <option value="MAR">March</option>
                                <option value="APR">April</option>
                                <option value="MAY">May</option>
                                <option value="JUN">June</option>
                                <option value="JUL">July</option>
                                <option value="AUG">Augest</option>
                                <option value="SEP">September</option>
                                <option value="OCT">October</option>
                                <option value="NOV">November</option>
                                <option value="DEC">December</option>
                           </select>
                        </div>
                    </div> 
                     
                    </div>
                     <div class="col-6">
                        <label class="form-label">Ending</label><span style='color:red'>*</span>
                            <div class="input-group">
                           <select class="form-select form-select-sm" name="EndingYear" id="EndingYear" onchange="EndingYear_Err()">
                            <option value="0">Year</option>
                            <?php for($year=date("Y");$year>(date("Y")-60);$year--) { ?>
                            <option value="<?php echo $year; ?>" <?php echo ($_POST['CaseYear']==$year) ? " selected='selected' " : "";?>><?php echo $year; ?></option>
                            <?php } ?>
                           </select>
                            <div class="input-group-prepend">
                              <select class="form-select form-select-sm" name="EndingMonth" id="EndingMonth" onchange="EndingMonth_Err()">
                                    <option value="0">Month</option>
                                    <option value="JAN">January</option>
                                    <option value="FEB">February</option>
                                    <option value="MAR">March</option>
                                    <option value="APR">April</option>
                                    <option value="MAY">May</option>
                                    <option value="JUN">June</option>
                                    <option value="JUL">July</option>
                                    <option value="AUG">Augest</option>
                                    <option value="SEP">September</option>
                                    <option value="OCT">October</option>
                                    <option value="NOV">November</option>
                                    <option value="DEC">December</option>
                           </select>
                        </div>
                    </div> 
                    </div>
                    <div class="col-6">
                    <span id="ErrStartingYear" class="error_msg" style="color: red; margin-bottom: 3px;"></span>  
                    </div>
                    <div class="col-6">
                        <span id="ErrEndingYear" class="error_msg" style="color: red; margin-bottom: 3px;"></span> 
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="Remarks_Err()"></input>
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                    
                </div>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()" class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Batch</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="editCode_Err()"></input>
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">Batch Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="BatchName" id="editBatchName" placeholder="Batch Name" value="<?php echo $data[0]['BatchName'];?>" onkeypress="editBatchName_Err()"></input>
                        <span id="ErreditBatchName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-6">
                        <label class="form-label">Starts</label><span style='color:red'>*</span>
                            <div class="input-group">
                           <select class="form-select form-select-sm" name="StartingYear" id="editStartingYear" onchange="editStartingYear_Err()">
                                <option value="0">Year</option>
                                <?php for($year=date("Y");$year>(date("Y")-60);$year--) { ?>
                                <option value="<?php echo $year; ?>" <?php echo ($_POST['CaseYear']==$year) ? " selected='selected' " : "";?>><?php echo $year; ?></option>
                                <?php } ?>
                           </select>
                            <div class="input-group-prepend">
                             <select class="form-select form-select-sm" name="StartingMonth" id="editStartingMonth" onchange="editStartingMonth_Err()">
                                <option value="0">Month</option>
                                <option value="JAN">January</option>
                                <option value="FEB">February</option>
                                <option value="MAR">March</option>
                                <option value="APR">April</option>
                                <option value="MAY">May</option>
                                <option value="JUN">June</option>
                                <option value="JUL">July</option>
                                <option value="AUG">Augest</option>
                                <option value="SEP">September</option>
                                <option value="OCT">October</option>
                                <option value="NOV">November</option>
                                <option value="DEC">December</option>
                           </select>
                        </div>
                    </div> 
                    </div>
                     <div class="col-6">
                        <label class="form-label">Ending</label><span style='color:red'>*</span>
                            <div class="input-group">
                           <select class="form-select form-select-sm" name="EndingYear" id="editEndingYear" onchange="editEndingYear_Err()">
                            <option value="0">Year</option>
                            <?php for($year=date("Y");$year>(date("Y")-60);$year--) { ?>
                            <option value="<?php echo $year; ?>" <?php echo ($_POST['CaseYear']==$year) ? " selected='selected' " : "";?>><?php echo $year; ?></option>
                            <?php } ?>
                           </select>
                            <div class="input-group-prepend">
                              <select class="form-select form-select-sm" name="EndingMonth" id="editEndingMonth" onchange="editEndingMonth_Err()">
                                    <option value="0">Month</option>
                                    <option value="JAN">January</option>
                                    <option value="FEB">February</option>
                                    <option value="MAR">March</option>
                                    <option value="APR">April</option>
                                    <option value="MAY">May</option>
                                    <option value="JUN">June</option>
                                    <option value="JUL">July</option>
                                    <option value="AUG">Augest</option>
                                    <option value="SEP">September</option>
                                    <option value="OCT">October</option>
                                    <option value="NOV">November</option>
                                    <option value="DEC">December</option>
                           </select>
                        </div>
                    </div> 
                    </div>
                    <div class="col-6">
                    <span id="ErreditStartingYear" class="error_msg" style="color: red; margin-bottom: 3px;"></span>  
                    </div>
                    <div class="col-6">
                        <span id="ErreditEndingYear" class="error_msg" style="color: red; margin-bottom: 3px;"></span> 
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="editShortCourseName_Err()"></input>
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Batch</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Code</div>
                        <?php echo $data[0]['Code'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Batch Name</div>
                        <?php echo $data[0]['BatchName'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Starting</div>
                        Year<?php echo $data[0]['StartingYear'];?> ,
                        Month<?php echo $data[0]['StartingMonth'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Ending</div>
                        Year<?php echo $data[0]['EndingYear'];?> ,
                        Month<?php echo $data[0]['EndingMonth'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                        <?php echo $data[0]['Remarks'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                        <?php echo $data[0]['Status'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                        <?php echo $data[0]['CreatedOn'];?>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-bs-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>
function view(){
      $('#confirmation').modal("show"); 
      
}

function addform(){
        $('#confirmationtoadd').modal("show"); 
        $('#Code').val(""); 
        $('#BatchName').val(""); 
        $('#StartingYear').val("0"); 
        $('#StartingMonth').val("0"); 
        $('#EndingYear').val("0"); 
        $('#EndingMonth').val("0"); 
        $('#Remarks').val("");
        
        $('#ErrCode').html("");
        $('#ErrBatchName').html(""); 
        $('#ErrStartingYear').html(""); 
        $('#ErrStartingMonth').html(""); 
        $('#ErrEndingYear').html(""); 
        $('#ErrEndingMonth').html(""); 
        $('#ErrRemarks').html(""); 
         
        $("#Code").removeClass("highlight_error");
        $("#BatchName").removeClass("highlight_error");
        $("#StartingYear").removeClass("highlight_error");
        $("#StartingMonth").removeClass("highlight_error");
        $("#EndingYear").removeClass("highlight_error");
        $("#EndingMonth").removeClass("highlight_error");
        $("#Remarks").removeClass("highlight_error");
}

function add(){
   var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
         $("#Code").addClass("highlight_error");
          error++;
    }  else {
        $("#Code").removeClass("highlight_error");
            $('#ErrCode').html(""); 
    }
    if ($('#BatchName').val()==""){
            $('#ErrBatchName').html("Please enter Batch Name");
            $("#BatchName").addClass("highlight_error");
          error++;
    }  else {
        $("#BatchName").removeClass("highlight_error");
            $('#ErrBatchName').html(""); 
    }
     if ($('#StartingYear').val()=="0") {
            $('#ErrStartingYear').html("Please select year");
           $("#Code").addClass("highlight_error");
           error++;
    }  else {
           if ($('#StartingMonth').val()=="0"){
            $('#ErrStartingYear').html("Please select month");
         $("#StartingMonth").addClass("highlight_error");
          error++;
    }  else {
           $("#StartingYear").removeClass("highlight_error");
            $('#ErrStartingYear').html("");  
    } 
    }  
   if ($('#EndingYear').val()=="0") {
            $('#ErrEndingYear').html("Please select year");
         $("#EndingYear").addClass("highlight_error");
           error++;
    }  else {
           if ($('#EndingMonth').val()=="0"){
            $('#ErrEndingYear').html("Please select month");
          $("#EndingMonth").addClass("highlight_error");
          error++;
    }  else {
          $("#EndingYear").removeClass("highlight_error");
            $('#ErrEndingYear').html("");  
    } 
    } 
     if (error==0){
       $('#confirmationtoadd').modal("hide"); 
       $('#Success').modal("show");  
    } 
   
}

function editform(){
     $('#confirmationtoedit').modal("show");
     $("#editCode").removeClass("highlight_error");
     $("#editBatchName").removeClass("highlight_error");
     $("#editStartingYear").removeClass("highlight_error");
     $("#editStartingMonth").removeClass("highlight_error");
     $("#editEndingYear").removeClass("highlight_error");
     $("#editEndingMonth").removeClass("highlight_error");
     $("#editRemarks").removeClass("highlight_error");
}

function edit(){
     var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
          editCode.style.border = "1px solid #dc3545";
          document.getElementById("editCode").style["boxShadow"] = "0 0 5px #dc3545";
           error++;
    }  else {
         document.getElementById("editCode").style["boxShadow"] = "";
            $('#ErreditCode').html(""); 
    }
     if ($('#editBatchName').val()==""){
            $('#ErreditBatchName').html("Please enter Batch Name");
          editBatchName.style.border = "1px solid #dc3545";
          document.getElementById("editBatchName").style["boxShadow"] = "0 0 5px #dc3545";
           error++;
    }  else {
         document.getElementById("editBatchName").style["boxShadow"] = "";
            $('#ErreditBatchName').html(""); 
    } 
    if ($('#editStartingYear').val()=="0") {
            $('#ErreditStartingYear').html("Please select year");
          editStartingYear.style.border = "1px solid #dc3545";
          document.getElementById("editStartingYear").style["boxShadow"] = "0 0 5px #dc3545";
           error++;
    }  else {
           if ($('#editStartingMonth').val()=="0"){
            $('#ErreditStartingYear').html("Please select month");
          editStartingMonth.style.border = "1px solid #dc3545";
          document.getElementById("editStartingMonth").style["boxShadow"] = "0 0 5px #dc3545";
          error++;
    }  else {
          document.getElementById("editStartingMonth").style["boxShadow"] = "";
            $('#ErreditStartingYear').html("");  
    } 
    }  
   if ($('#editEndingYear').val()=="0") {
            $('#ErreditEndingYear').html("Please select year");
          editEndingYear.style.border = "1px solid #dc3545";
          document.getElementById("editEndingYear").style["boxShadow"] = "0 0 5px #dc3545";
           error++;
    }  else {
           if ($('#editEndingMonth').val()=="0"){
            $('#ErreditEndingYear').html("Please select month");
          editEndingMonth.style.border = "1px solid #dc3545";
          document.getElementById("editEndingMonth").style["boxShadow"] = "0 0 5px #dc3545";
          error++;
    }  else {
          document.getElementById("editEndingMonth").style["boxShadow"] = "";
            $('#ErreditEndingYear').html("");  
    } 
    } 
   
    if (error==0){
       $('#confirmationtoedit').modal("hide"); 
       $('#Success').modal("show");  
    } 
}

function viewform(){
     $('#confirmationtoview').modal("show"); 
}

function Code_Err() {                                                           
     $('#ErrCode').html("");
      document.getElementById("Code").style["boxShadow"] = "";
      Code.style.border = "1px solid #4776e6";
 } 
 
function BatchName_Err() {
     $('#ErrBatchName').html("");
      document.getElementById("BatchName").style["boxShadow"] = "";
      BatchName.style.border = "1px solid #4776e6";
 }
 function StartingYear_Err() {
     $('#ErrStartingYear').html("");
      document.getElementById("StartingYear").style["boxShadow"] = "";
      StartingYear.style.border = "1px solid #4776e6";
 } 
 function EndingYear_Err() {
     $('#ErrEndingYear').html("");
      document.getElementById("EndingYear").style["boxShadow"] = "";
      EndingYear.style.border = "1px solid #4776e6";
 } 
 function StartingMonth_Err() {
     $('#ErrStartingMonth').html("");
      document.getElementById("StartingMonth").style["boxShadow"] = "";
      StartingMonth.style.border = "1px solid #4776e6";
 } 
 function EndingMonth_Err() {
     $('#ErrEndingMonth').html("");
      document.getElementById("EndingMonth").style["boxShadow"] = "";
      EndingMonth.style.border = "1px solid #4776e6";
 }


 function editCode_Err() {
     $('#ErreditCode').html("");
      document.getElementById("editCode").style["boxShadow"] = "";
      editCode.style.border = "1px solid #4776e6";
 } 
 function editBatchName_Err() {
     $('#ErreditBatchName').html("");
      document.getElementById("editBatchName").style["boxShadow"] = "";
      editBatchName.style.border = "1px solid #4776e6";
 } 
  function editStartingYear_Err() {
     $('#ErreditStartingYear').html("");
      document.getElementById("editStartingYear").style["boxShadow"] = "";
      editStartingYear.style.border = "1px solid #4776e6";
 } 
 function editEndingYear_Err() {
     $('#ErreditEndingYear').html("");
      document.getElementById("editEndingYear").style["boxShadow"] = "";
      editEndingYear.style.border = "1px solid #4776e6";
 } 
 function editStartingMonth_Err() {
     $('#ErreditStartingMonth').html("");
      document.getElementById("editStartingMonth").style["boxShadow"] = "";
      editStartingMonth.style.border = "1px solid #4776e6";
 } 
 function editEndingMonth_Err() {
     $('#ErreditEndingMonth').html("");
      document.getElementById("editEndingMonth").style["boxShadow"] = "";
      editEndingMonth.style.border = "1px solid #4776e6";
 }
 


function dashboard()  {
  location.href='dashboard.php';                                                              
}

//Character Limitations

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphanumeric Space Dot only correct */ 
var arr = ["BatchName","editBatchName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            console.log(e.keyCode);
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [190,32,96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}
  
</script>
    